@@ -12,9 +12,6 @@
 #define NO_GDAL_CPP_HEADERS
 #include "gdal_sf_pkg.h"
 
-#if GDAL_VERSION_NUM >= 2010000
-# include "gdal_utils.h" // requires >= 2.1
-
 /* modified from GDALTermProgress: */
 int CPL_STDCALL GDALRProgress( double dfComplete,
                                   CPL_UNUSED const char * pszMessage,
@@ -46,6 +43,9 @@ int CPL_STDCALL GDALRProgress( double dfComplete,
     return TRUE;
 }
 
+#if GDAL_VERSION_NUM >= 2010000
+# include "gdal_utils.h" // requires >= 2.1
+
 // [[Rcpp::export]]
 Rcpp::CharacterVector CPL_gdalinfo(Rcpp::CharacterVector obj, Rcpp::CharacterVector options, 
 		Rcpp::CharacterVector oo) {
@@ -457,7 +457,7 @@ Rcpp::LogicalVector CPL_gdal_warper(Rcpp::CharacterVector infile, Rcpp::Characte
 		(int *) CPLMalloc(sizeof(int) * psWarpOptions->nBandCount );
 	psWarpOptions->panDstBands =
 		(int *) CPLMalloc(sizeof(int) * psWarpOptions->nBandCount );
-	for (size_t i = 0; i < psWarpOptions->nBandCount; i++) {
+	for (int i = 0; i < psWarpOptions->nBandCount; i++) {
 		psWarpOptions->panSrcBands[i] = i + 1;
 		psWarpOptions->panDstBands[i] = i + 1;
 	}
@@ -471,17 +471,17 @@ Rcpp::LogicalVector CPL_gdal_warper(Rcpp::CharacterVector infile, Rcpp::Characte
 	for (int i = 0; i < GDALGetRasterCount(hSrcDS); i++) {
 		poBand = GDALGetRasterBand(hSrcDS, i + 1);
 		GDALGetRasterNoDataValue(poBand, &success);
-		if (success)
+		if (success) {
 			psWarpOptions->padfSrcNoDataReal[i] = GDALGetRasterNoDataValue(poBand, &success);
-			// Rcpp::Rcout << GDALGetRasterNoDataValue(poBand, &success) << std::endl;
-		else
+			// Rcpp::Rcout << "1: " << GDALGetRasterNoDataValue(poBand, &success) << std::endl;
+		 } else
 			memcpy(&(psWarpOptions->padfSrcNoDataReal[i]), &d, sizeof(double));
 		poBand = GDALGetRasterBand(hDstDS, i + 1);
 		GDALGetRasterNoDataValue(poBand, &success);
-		if (success)
-			psWarpOptions->padfDstNoDataReal[0] = GDALGetRasterNoDataValue(poBand, &success);
-			// Rcpp::Rcout << GDALGetRasterNoDataValue(poBand, &success) << std::endl;
-		else // NaN:
+		if (success) {
+			psWarpOptions->padfDstNoDataReal[i] = GDALGetRasterNoDataValue(poBand, &success);
+			// Rcpp::Rcout << "2: " << GDALGetRasterNoDataValue(poBand, &success) << std::endl;
+		} else // NaN:
 			memcpy(&(psWarpOptions->padfDstNoDataReal[i]), &d, sizeof(double));
 	}
 
